@@ -19,7 +19,7 @@ use Types::Standard qw/Str Int Bool HashRef/;
 use Type::Utils;
 use Module::Pluggable require => 1, search_path => ['Group::Git::Cmd', 'Group::Git::Taggers'];
 
-our $VERSION = version->new('0.5.10');
+our $VERSION = version->new('0.6.0');
 our $AUTOLOAD;
 
 has conf => (
@@ -98,12 +98,15 @@ sub _repos {
             $url = '';
         }
 
+        my $glob = "$file/.*.tag";
+        $glob =~ s/\s/?/g;
+
         $repos{$file} = Group::Git::Repo->new(
             name => $file,
             git  => $url,
             tags => {
-                map {m{/[.](.*?)[.]tag$}; $1 => 1}
-                glob "$file/.*.tag"
+                map { m{/[.](.*?)[.]tag$}; $1 => 1 }
+                glob $glob
             },
         );
 
@@ -162,7 +165,7 @@ Group::Git - Base module for group of git repository operations.
 
 =head1 VERSION
 
-This documentation refers to Group::Git version 0.5.10.
+This documentation refers to Group::Git version 0.6.0.
 
 =head1 SYNOPSIS
 
