@@ -15,7 +15,7 @@ use English qw/ -no_match_vars /;
 use File::chdir;
 use Getopt::Alt;
 
-our $VERSION = version->new('0.5.10');
+our $VERSION = version->new('0.6.0');
 
 requires 'repos';
 requires 'verbose';
@@ -71,6 +71,18 @@ sub pull {
     my $dir;
 
     if ( -d $name ) {
+        {
+            local $CWD = $name;
+
+            # check that there is a remote
+            my $remotes = `git remote 2> /dev/null`;
+            chomp $remotes;
+
+            if ( ! $remotes && ! $self->verbose ) {
+                return;
+            }
+        }
+
         $dir = $name;
         my @args = map {
                 $opt->opt->{$_} eq '0'   ? "--no-$_"
@@ -108,7 +120,7 @@ Group::Git::Cmd::Pull - Pull latest versions of all repositories or clone any th
 
 =head1 VERSION
 
-This documentation refers to Group::Git::Cmd::Pull version 0.5.10.
+This documentation refers to Group::Git::Cmd::Pull version 0.6.0.
 
 =head1 SYNOPSIS
 
